@@ -759,7 +759,7 @@ class CasinosExtension(Extension):
     def _render(self, args, caller=None):
         logger.info('casinos Args IN: {0}'.format(args))
 
-        default = [10, 'casinos_top', True, None] # cnt, template, has_geo, sort, [tags...]
+        default = [10, 'casinos_top', True, False, None] # cnt, template, has_geo, has_append, sort, [tags...]
         _ca = len(default)
         args = args[:_ca] + default[len(args):] + args[_ca:]
 
@@ -768,66 +768,58 @@ class CasinosExtension(Extension):
         count = int(args[0])
         template = args[1]
         has_geo = bool(args[2])
-        sorting = args[3]
+        has_append = bool(args[3])
+        sorting = args[4]
 
         tags = args[len(default):]
         logger.info('casinos Tags: {0}'.format(tags))
 
-        if False:
-            pass
-            # _afields = ['software', 'licences', 'deposits', 'withdrawal', 'games']
-            # _aggs = {
-            #     item: {
-            #         "terms": {
-            #             "field": "{0}.keyword".format(item),
-            #             "size": 500,
-            #             "order": {"_key": "asc"}
-            #         }
-            #     } for item in _afields
-            # }
+        kwargs = {
+            'is_searchable': True,
+            'is_redirect': False,
+            'country': current_user.country_full if has_geo else None,
+            'provider_tags': tags,
+            '_source': True, 
+            '_count': count,
+            '_sorting': sorting,
+        }
+        if len(current_app.config['AVAILABLE_LOCALE']) > 1:
+            kwargs['locale_available'] = g.language
 
-            # args: service
-            # pages, found, aggs, id = Page.provider_by_context(
-            #     is_searchable=True,
-            #     is_redirect=False,
-            #     country=current_user.country_full,
-            #     services=service,
-            #     provider_tags=tags,
-            #     _source = True, 
-            #     _count=count,
-            #     _aggs = _aggs
-            # )
-            # if id and has_filters:
-            #     _c = dumps(aggs)
-            #     current_app.redis.hset('aggs', id, _c)
-            #     logger.info('Cache aggs {0}: {1}'.format(id, len(_c)))
-        else:
+        pages, found = Page.provider_by_context(**kwargs)
+        logger.info(f'Casinos found: {found}')
+
+        if has_append and has_geo and found < count and tags:
             kwargs = {
                 'is_searchable': True,
                 'is_redirect': False,
+                'country': None,
                 'country': current_user.country_full if has_geo else None,
-                # 'services': 'casino',
-                'provider_tags': tags,
                 '_source': True, 
-                '_count': count,
-                '_sorting': sorting,
+                '_count': count - found,
+                '_exclude': [casino._id for casino in pages],
             }
             if len(current_app.config['AVAILABLE_LOCALE']) > 1:
                 kwargs['locale_available'] = g.language
 
-            pages, found = Page.provider_by_context(**kwargs)
-            logger.info(f'Casinos found: {found}')
+            pages_level_2, found_level_2 = Page.provider_by_context(**kwargs)
+            logger.info(f'Casinos level-2 found: {found_level_2}')
+            pages += pages_level_2
 
         now = pendulum.now('UTC')
 
-        t = current_app.jinja_env.get_template('_ext-{0}.html'.format(template))
-        s = t.render(
-            pages=pages, 
-            found=found, 
-            # has_filters=has_filters, 
-            count=count,
-            my=now.format('MMMM YYYY'),
-        )
+        s = str(args)
+        try:
+            t = current_app.jinja_env.get_template('_ext-{0}.html'.format(template))
+            s = t.render(
+                pages=pages, 
+                found=found, 
+                count=count,
+                my=now.format('MMMM YYYY'),
+            )
+        except TemplateNotFound:
+            pass
+
         return s
 
     def parse(self, parser):
