@@ -448,6 +448,8 @@ class Page(ElasticEntity):
         'withdrawal': list,
         'min_deposit': int,
         'min_withdrawal': int,
+        'min_deposit_float': float,
+        'min_withdrawal_float': float,
         'cashiers_limits': list,
         'games_limits': list,
         'withdrawal_time': list,
@@ -1212,6 +1214,7 @@ class Activity(ElasticEntity):
         'status': str,
         'replies': list,
         'is_active': bool,
+        'comment': str,
 
         # click
         'url': str,
@@ -1817,12 +1820,17 @@ class ActivityFeedbackModel(BaseModel):
 class ActivityComplaintModel(BaseModel):
     casino: str = ...
     amount: str = ...
-    currency: str = ...
+    # currency: str = ...
     message: str = ...
     subject: str = ...
     username: str = ...
     email: EmailStr
 
+    @validator('casino', 'message', 'subject', allow_reuse=True)
+    def not_empty(cls, v):
+        assert v != '', 'Required field'
+        return v
+
 
 class ComplaintModel(BaseModel):
     @validator('*', pre=True, allow_reuse=True)
@@ -1831,14 +1839,14 @@ class ComplaintModel(BaseModel):
             return None
         return v
 
-    name: str = ...
-    username: str = ...
-    email: EmailStr
+    username: str = None
+    email: EmailStr = None
     country: str = ...
     casino_selected: dict = ...
-    amount: str = ...
-    currency: str = ...
-    message: str = ...
+    amount: str = None
+    currency: str = None
+    message: str = None
+    comment: str = None
     status: str = ...
     subject: Optional[str] = None
     ip: str = ...
